@@ -5,34 +5,49 @@
 #   |  __/| |_| |  _|    _   _   / ___ \|  __/| |   / __/
 #   |_|   |____/|_|     (_) (_) /_/   \_\_|  |___| |_____|
 #
-#   Copyright 1999-2001 Alfred Reibenschuh <areibens@cpan.org>.
+#   A Perl Module Chain to faciliate the Creation and Modification
+#   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   This library is free software; you can redistribute it
-#   and/or modify it under the same terms as Perl itself.
+#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
-#   PDF::API2::Annotation
+#   This library is free software; you can redistribute it and/or
+#   modify it under the terms of the GNU Lesser General Public
+#   License as published by the Free Software Foundation; either
+#   version 2 of the License, or (at your option) any later version.
+#
+#   This library is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+#   Lesser General Public License for more details.
+#
+#   You should have received a copy of the GNU Lesser General Public
+#   License along with this library; if not, write to the
+#   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+#   Boston, MA 02111-1307, USA.
+#
+#   $Id: Annotation.pm,v 1.5 2003/12/08 13:05:18 Administrator Exp $
 #
 #=======================================================================
 package PDF::API2::Annotation;
 
-use strict;
-use vars qw(@ISA $VERSION);
-@ISA = qw(PDF::API2::PDF::Dict);
-( $VERSION ) = '$Revisioning: 0.3r74             Wed Jun 25 22:22:03 2003 $' =~ /\$Revisioning:\s+([^\s]+)/;
+BEGIN {
 
+    use strict;
+    use vars qw(@ISA $VERSION);
 
-use PDF::API2::PDF::Dict;
-use PDF::API2::PDF::Utils;
-use Math::Trig;
-use PDF::API2::Util;
+    use PDF::API2::Basic::PDF::Dict;
+    use PDF::API2::Basic::PDF::Utils;
+    use PDF::API2::Util;
 
-=head2 PDF::API2::Annotation
+    @ISA = qw(PDF::API2::Basic::PDF::Dict);
 
-Subclassed from PDF::API2::PDF::Dict.
+    ( $VERSION ) = '$Revision: 1.5 $' =~ /Revision: (\S+)\s/; # $Date: 2003/12/08 13:05:18 $
 
-=item $ant = PDF::API2::Annotation->new
+}
+
+=head1 $ant = PDF::API2::Annotation->new
 
 Returns a annotation object (called from $page->annotation).
 
@@ -309,4 +324,17 @@ __END__
 
 alfred reibenschuh
 
+=head1 HISTORY
+
+    $Log: Annotation.pm,v $
+    Revision 1.5  2003/12/08 13:05:18  Administrator
+    corrected to proper licencing statement
+
+    Revision 1.4  2003/12/08 11:55:17  Administrator
+    change for proper module versioning
+
+    Revision 1.3  2003/11/30 17:08:11  Administrator
+    merged into default
+
+
 =cut
